@@ -373,9 +373,10 @@ class RestAPI(object):
 						if silent == False: print(f"Error: {response['error']}")
 						return response
 		# reset.
+		__plans__ = {}
 		for plan in list(self.__plans__.keys()):
-			self.__plans__[plan]["api_keys"] = []
-		self.uid_api_keys = {}
+			__plans__[plan] = {"api_keys":[]}
+		__uid_api_keys__ = {}
 
 		# iterate users.
 		for user in self.firebase.users.iterate():
@@ -409,13 +410,19 @@ class RestAPI(object):
 			# map api keys.
 			plan = data["membership"]
 			api_key = data["api_key"]
-			try: self.__plans__[plan]
+			try: __plans__[plan]
 			except KeyError: 
 				return r3sponse.error_response(f"Failed to synchronize the users, user [{uid}] has an unknown membership [{plan}].", log_level=log_level, save=True)
-			self.__plans__[plan]["api_keys"].append(api_key)
+			if api_key not in __plans__[plan]["api_keys"]: 
+				__plans__[plan]["api_keys"].append(api_key)
 
 			# map uid api key.
-			self.uid_api_keys[uid] = api_key
+			__uid_api_keys__[uid] = api_key
+
+		# set.
+		self.uid_api_keys = __uid_api_keys__
+		for plan in list(self.__plans__.keys()):
+			self.__plans__[plan]["api_keys"] = __plans__[plan]["api_keys"]
 
 		# success response.
 		return r3sponse.success_response("Successfully synchronized the users.", log_level=log_level)
